@@ -10,7 +10,7 @@ import os
 import json
 import requests
 import logging
-import urllib2
+from six.moves.urllib.request import urlopen
 import csv
 
 # hwrt modules
@@ -180,7 +180,7 @@ def work():
     for i in range(1000):
         # contact the write-math server and get something to classify
         url = "http://www.martin-thoma.de/write-math/get_unclassified/"
-        response = urllib2.urlopen(url)
+        response = urlopen(url)
         page_source = response.read()
         parsed_json = json.loads(page_source)
         raw_data_json = parsed_json['recording']
